[TOC]

Usage
=====
All kinds of inner objects of the globals (As writing in the main) are placed here.

Objects
-------

### Season
An inner object of Seasons. Hold frozenset of animes in the specific season (by name and year).

### Review
Holds data about a Review of manga or anime

###Recommentions
holds data from an anime or manga
